@@ -44,7 +44,7 @@ our @EXPORT_OK = qw(get post put delete postFile putFile);
 ## CONSTANTS
 #####
 our $TIMEOUT = 10;
-our $VERSION = "1.2.3";
+our $VERSION = "1.2.4";
 #####
 ## VARIABLES
 #####
@@ -61,7 +61,7 @@ sub new {
 		'login'		=> $args{'login'},
 		'token'		=> $args{'token'},
 		'password'	=> $args{'password'},
-		'debug'		=> $args{'debug'}, || 0
+		'debug'		=> $args{'debug'} || 0,
 		'verbose'	=> $args{'verbose'} || 0,
 		'result'	=> undef,
 	};
@@ -135,7 +135,7 @@ sub new {
 	$self->{'result'}->{'httpstatus'} = $rc;
 
 # done, bless object and return it
-	bless ($self, $class)
+	bless ($self, $class);
 	$self->_logV1 ("Connected to $self->{'url'}");
 	$self->_logD($self);
 	return $self;
@@ -322,13 +322,25 @@ sub _logV1() {
 	my $self = shift;
 	my $msg = shift;
 
-	print "$msg\n" if ($self->verbose >= 1);
+	if ($self->{'verbose'} >= 1) {
+		if (defined $msg) {
+			print "$msg\n";
+		} else {
+			print "unknown $!";
+		}
+	}
 }
 sub _logV2() {
 	my $self = shift;
 	my $obj = shift;
 
-	print Dumper ($obj) if ($self->verbose >= 2);
+	if ($self->{'verbose'} >= 2) {
+		if (defined $obj) {
+			print Dumper ($obj);
+		} else {
+			print "unknown objetc $!";
+		}
+	}
 }
 
 sub _logD() {
